using FluentValidation;
using ldap_cesi.DTOs.Inputs.Salarie;

namespace ldap_cesi.Validator.Salarie;

public class SalarieCreateValidator : AbstractValidator<SalarieCreateDto>
{
    public SalarieCreateValidator()
    {
        RuleFor(x => x.Nom)
            .NotEmpty().WithMessage("Le nom est requis.")
            .MaximumLength(50).WithMessage("Le nom ne doit pas dépasser 50 caractères.");

        RuleFor(x => x.Prenom)
            .NotEmpty().WithMessage("Le prénom est requis.")
            .MaximumLength(50).WithMessage("Le prénom ne doit pas dépasser 50 caractères.");

        RuleFor(x => x.TelephoneFix)
            .NotEmpty().WithMessage("Le téléphone fixe est requis.")
            .MaximumLength(15).WithMessage("Le téléphone fixe ne doit pas dépasser 15 caractères.");

        RuleFor(x => x.TelephonePortable)
            .NotEmpty().WithMessage("Le téléphone portable est requis.")
            .MaximumLength(15).WithMessage("Le téléphone portable ne doit pas dépasser 15 caractères.");

        RuleFor(x => x.Email)
            .NotEmpty().WithMessage("L'email est requis.")
            .EmailAddress().WithMessage("L'email n'est pas valide.")
            .MaximumLength(50).WithMessage("L'email ne doit pas dépasser 50 caractères.");

        RuleFor(x => x.IdSite)
            .NotEmpty().WithMessage("L'ID du site est requis.");

        RuleFor(x => x.IdService)
            .NotEmpty().WithMessage("L'ID du service est requis.");
    }
}